@@ -19,7 +19,7 @@ from docstring_parser import parse, Docstring, DocstringParam  # type: ignore
 from .format import Color, format_text, get_underline
 
 
-__VERSION__ = "0.3.1"
+__VERSION__ = "0.3.3"
 
 
 # If an annotation is one of these values, we will convert the string value
@@ -160,7 +160,7 @@ class Command:
         if self.arguments_description:
             print(self.arguments_description)
         else:
-            print("No args")
+            print("No args\n")
 
         if self.aliases:
             print("Aliases")
@@ -227,6 +227,19 @@ class CLI:
     description: str = "Targ CLI"
     commands: t.List[Command] = field(default_factory=list)
 
+    def command_exists(self, group_name: str, command_name: str) -> bool:
+        """
+        This isn't used by Targ itself, but is useful for third party code
+        which wants to inspect the CLI, so don't remove it.
+        """
+        for command in self.commands:
+            if (
+                command.group_name == group_name
+                and command.command_name == command_name
+            ):
+                return True
+        return False
+
     def _validate_name(self, name: str) -> bool:
         """
         Any custom names provided by user should not contain spaces (i.e.
